# 
#   Copyright (C) 2001-2002 by Ernesto Rico-Schmidt <nene@sbox.tugraz.at>
#
#   This program is free software; you can redistribute it and/or modify it
#   under the terms of the GNU General Public License as published by the Free
#   Software Foundation; either version 2 of the License, or (at your option)
#   any later version.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
#   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
#   for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program; if not, write to the Free Software Foundation, Inc., 59
#   Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: schema.sql,v 1.1 2002/08/26 08:31:32 ernesto Exp $

# termine:              # rhytmus:
#   0 = montag		 #   0 = einmalig
#   1 = dienstag	 #   1 = monatlich am 1.
#   2 = mittwoch	 #   2 = monatlich am 2.
#   3 = donnerstag	 #   3 = monatlich am 3.
#   4 = freitag		 #   4 = monatlich am 4.
#   5 = samstag		 #   5 = monatlich am 5. (?)
#   6 = sonntag		 #   7 = wchentlich
#			 #   14 = 14-tgig
#                        #   50 = montag bis freitag
#                        #   70 = tglich
#
# entspricht dem Format von weekday() in MySQL
#
CREATE TABLE sendungen (
       id			SMALLINT UNSIGNED NOT NULL auto_increment,
       titel			CHAR(100) NOT NULL,
       beginn			TIME NOT NULL,
       ende			TIME NOT NULL,
       termin			TINYINT UNSIGNED NOT NULL,
       rhytmus			TINYINT UNSIGNED NOT NULL,
       erster_termin		DATE NOT NULL,
       letzter_termin		DATE NOT NULL,
       beschreibung		TEXT NOT NULL,
       web			CHAR(100) DEFAULT '',
       email			CHAR(40) DEFAULT '',
       macher			CHAR(100) DEFAULT '',
       eingegeben_am		DATETIME NOT NULL,
       eingegeben_von		CHAR(20) NOT NULL,
       aktualisiert_am		DATETIME DEFAULT '',
       aktualisiert_von		CHAR(20) DEFAULT '',

       bemerkungen		TEXT DEFAULT '',

       PRIMARY KEY(id)
);

# 
#
CREATE TABLE verantwortliche (
       id			SMALLINT UNSIGNED NOT NULL auto_increment,
       vorname			CHAR(20) NOT NULL,
       nachname			CHAR(20) NOT NULL,
       nickname			CHAR(20) DEFAULT '',
       telefon1			CHAR(20) NOT NULL,
       telefon1_art		ENUM('bro', 'privat', 'mobil') 
					DEFAULT 'privat',
       telefon2			CHAR(20) DEFAULT '',
       telefon2_art		ENUM('bro', 'privat', 'mobil')
					DEFAULT 'bro',
       email			CHAR(40) DEFAULT '',
       adresse			CHAR(40) NOT NULL,
       plz			CHAR(4) NOT NULL,
       ort			CHAR(20) NOT NULL,

       haftung			ENUM('ja', 'nein') DEFAULT 'nein',
       haftung_am		DATETIME DEFAULT '',
       eingegeben_am		DATETIME NOT NULL,
       eingegeben_von		CHAR(20) NOT NULL,
       aktualisiert_am		DATETIME DEFAULT '',
       aktualisiert_von		CHAR(20) DEFAULT '',

       bemerkungen		TEXT DEFAULT '',

       PRIMARY KEY(id)
);

#
#
CREATE TABLE notizen (
       id			SMALLINT UNSIGNED NOT NULL auto_increment,
       sendung_id		SMALLINT UNSIGNED NOT NULL,
       datum			DATE NOT NULL,
       notiz			TEXT NOT NULL,

       eingegeben_am		DATETIME NOT NULL,
       eingegeben_von		CHAR(20) NOT NULL,
       aktualisiert_am		DATETIME DEFAULT '',
       aktualisiert_von		CHAR(20) DEFAULT '',

       PRIMARY KEY(id, sendung_id)
);

# redakteure.id entscpricht dem verantwortliche.id
#
CREATE TABLE redakteure (
       id			SMALLINT UNSIGNED NOT NULL,
       name			CHAR(15) NOT NULL,
       passwort			CHAR(15) NOT NULL,

       bemerkungen		TEXT DEFAULT '',

       PRIMARY KEY(id)
);

# benutzer.id entpspricht dem verantwortliche.id
#
CREATE TABLE benutzer (
       id			SMALLINT UNSIGNED NOT NULL,
       name			CHAR(15) NOT NULL,
       passwort			CHAR(15) NOT NULL,
       email			CHAR(40) DEFAULT '',

       bemerkungen		TEXT DEFAULT '',

       PRIMARY KEY(id)
);

CREATE TABLE benutzerrechte (
       id			SMALLINT UNSIGNED NOT NULL auto_increment,
       benutzer_id		SMALLINT UNSIGNED NOT NULL,
       sendung_id		SMALLINT UNSIGNED NOT NULL,

       bemerkungen		TEXT DEFAULT '',

       PRIMARY KEY(id, benutzer_id, sendung_id)
);
